#include <GroveDriverPack.h>
#include <Adafruit_TinyUSB.h>
#include <WioCellular.hpp>

////////////////////////////////////////////////////////////////////////////////
// Defines

#define BOOT_INTERVAL   (60)  // [sec.]

////////////////////////////////////////////////////////////////////////////////
// Global variables

GroveBoard Board;
WioExtRTC ExtRTC(&Board.I2C);

////////////////////////////////////////////////////////////////////////////////
// setup and loop

void setup()
{
  Serial.begin(115200);
  {
    const auto start = millis();
    while (!Serial && millis() - start < 5000) {
      delay(2);
    }
  }
  Serial.println();
  Serial.println();

  Serial.println("--- START ---");

  ////////////////////////////////////////
  // Low-level initialize

  Serial.println("### I/O Initialize.");
  WioCellular.begin();

  Serial.println("### Power supply ON.");
  WioCellular.enableGrovePower();
  delay(500);
  
  ////////////////////////////////////////
  // Device initialize
  
  Serial.println("### Device initialize.");
  Board.I2C.Enable();
  ExtRTC.Init();

  ////////////////////////////////////////
  // Completed

  Serial.println("### Completed.");
}

void loop()
{
  /*
  uint8_t val;
  ExtRTC.Eeprom.Read(0, &val, sizeof(val));
  Serial.print("EEPROM value is ");
  Serial.println(val);
  
  val++;
  ExtRTC.Eeprom.Write(0, &val, sizeof(val));
  */

  Serial.println("Flash.");
  for (int i = 0; i < 10; i++) {
    digitalWrite(LED_BUILTIN, HIGH);
    delay(200);
    digitalWrite(LED_BUILTIN, LOW);
    delay(200);
  }
  
  Serial.println("Shutdown.");
  delay(200);

  ExtRTC.SetWakeupPeriod(BOOT_INTERVAL);
  ExtRTC.Shutdown();
  while (1) {}
}

////////////////////////////////////////////////////////////////////////////////
